@@ -21,6 +21,7 @@ https://blockattack.net
 ===========================================================================
 */
 
+#include "HelpCommon.hpp"
 #include "HelpGamepadState.hpp"
 #include "global.hpp"
 #include "common.h"
@@ -29,31 +30,8 @@ https://blockattack.net
 
 const int buttonOffset = 160;
 
-static void setHelpGamepadFont(const sago::SagoDataHolder* holder, sago::SagoTextField& field, const char* text) {
-	field.SetHolder(holder);
-	field.SetFont("freeserif");
-	field.SetColor({255,255,255,255});
-	field.SetFontSize(30);
-	field.SetOutline(2, {0,0,0,255});
-	field.SetText(text);
-}
 
-static void setHelpGamepadFont(const sago::SagoDataHolder* holder, sago::SagoTextBox& field, const char* text) {
-	field.SetHolder(holder);
-	field.SetFont("freeserif");
-	field.SetColor({255,255,255,255});
-	field.SetFontSize(30);
-	field.SetOutline(2, {0,0,0,255});
-	field.SetText(text);
-}
-
-
-HelpGamepadState::HelpGamepadState() {
-	setHelpGamepadFont(&globalData.spriteHolder->GetDataHolder(), moveLabel, _("Move cursor"));
-	setHelpGamepadFont(&globalData.spriteHolder->GetDataHolder(), pushLabel, _("Push line"));
-	setHelpGamepadFont(&globalData.spriteHolder->GetDataHolder(), backLabel, _("Back (Menu)"));
-	setHelpGamepadFont(&globalData.spriteHolder->GetDataHolder(), switchLabel, _("Switch"));
-	setHelpGamepadFont(&globalData.spriteHolder->GetDataHolder(), confirmLabel, _("Confirm"));
+static std::string getLabelForSupportedControllerNames() {
 	std::string s = _("Only SDL2 compatible controllers are supported!\nSupported controllers: ");
 	for (size_t i = 0 ; i<GetSupportedControllerNames().size(); ++i ) {
 		if (i != 0) {
@@ -61,7 +39,18 @@ HelpGamepadState::HelpGamepadState() {
 		}
 		s+= GetSupportedControllerNames().at(i);
 	}
-	setHelpGamepadFont(&globalData.spriteHolder->GetDataHolder(), supportedControllers, s.c_str());
+	return s;
+}
+
+
+HelpGamepadState::HelpGamepadState() {
+	setHelp30Font(&globalData.spriteHolder->GetDataHolder(), moveLabel, _("Move cursor"));
+	setHelp30Font(&globalData.spriteHolder->GetDataHolder(), pushLabel, _("Push line"));
+	setHelp30Font(&globalData.spriteHolder->GetDataHolder(), backLabel, _("Back (Menu)"));
+	setHelp30Font(&globalData.spriteHolder->GetDataHolder(), switchLabel, _("Switch"));
+	setHelp30Font(&globalData.spriteHolder->GetDataHolder(), confirmLabel, _("Confirm"));
+	std::string s = getLabelForSupportedControllerNames();
+	setHelp30Font(&globalData.spriteHolder->GetDataHolder(), supportedControllers, s.c_str());
 	supportedControllers.SetMaxWidth(740);
 }
 
@@ -75,6 +64,14 @@ bool HelpGamepadState::IsActive() {
 void HelpGamepadState::ProcessInput(const SDL_Event& event, bool& processed) {
 	UpdateMouseCoordinates(event, globalData.mousex, globalData.mousey);
 
+	if (isGameControllerConnectionEvent(event)) {
+		UnInitGameControllers();
+		InitGameControllers();
+		std::string s = getLabelForSupportedControllerNames();
+		setHelp30Font(&globalData.spriteHolder->GetDataHolder(), supportedControllers, s.c_str());
+		processed = true;
+	}
+
 	if (isConfirmEvent(event) || isEscapeEvent(event)) {
 		isActive = false;
 		processed = true;
@@ -102,13 +99,13 @@ void HelpGamepadState::Draw(SDL_Renderer* target) {
 	SDL_RenderDrawLine(target, globalData.xsize/2, 80, globalData.xsize/2, 90);
 	pushLabel.Draw(target, globalData.xsize/2, 80, sago::SagoTextField::Alignment::center, sago::SagoTextField::VerticalAlignment::bottom);
 	//Back lines
-	SDL_RenderDrawLine(target, 625+OFFSETX, 168, 800+OFFSETX, 168);
-	SDL_RenderDrawLine(target, 800+OFFSETX, 158, 800+OFFSETX, 195);
-	SDL_RenderDrawLine(target, 490+OFFSETX, 195, 800+OFFSETX, 195);
+	SDL_RenderDrawLine(target, 800+OFFSETX, 158, 800+OFFSETX, 207);
+	SDL_RenderDrawLine(target, 490+OFFSETX, 180, 800+OFFSETX, 180);
+	SDL_RenderDrawLine(target, 490+OFFSETX, 180, 490+OFFSETX, 195);
+	SDL_RenderDrawLine(target, 663+OFFSETX, 207, 800+OFFSETX, 207);
 	backLabel.Draw(target, 800+OFFSETX, 156, sago::SagoTextField::Alignment::center, sago::SagoTextField::VerticalAlignment::bottom);
 	SDL_RenderDrawLine(target, 625+OFFSETX, 241, 900+OFFSETX, 241);
-	SDL_RenderDrawLine(target, 663+OFFSETX, 207, 900+OFFSETX, 207);
-	SDL_RenderDrawLine(target, 900+OFFSETX, 207, 900+OFFSETX, 400);
+	SDL_RenderDrawLine(target, 900+OFFSETX, 241, 900+OFFSETX, 400);
 	switchLabel.Draw(target, 900+OFFSETX, 404, sago::SagoTextField::Alignment::center);
 	confirmLabel.Draw(target, 900+OFFSETX, 404+30, sago::SagoTextField::Alignment::center);
 	bExit.Draw(globalData.screen, SDL_GetTicks(), globalData.xsize-buttonOffset, globalData.ysize-buttonOffset);
@@ -140,4 +137,4 @@ void HelpGamepadState::Update() {
 		}
 
 	}
-}
\ No newline at end of file
+}
