@@ -59,16 +59,6 @@ sago::SagoTextField* ButtonGfx::getLabel(const std::string& text) {
 	return labels[text].get();
 }
 
-Button::Button() {
-	label = "";
-	marked = false;
-	action = nullptr;
-	popOnRun = false;
-}
-
-Button::~Button() {
-}
-
 Button::Button(const Button& b) : action{b.action}, label{b.label}, marked{b.marked} {
 }
 
@@ -152,17 +142,11 @@ void Menu::addButton(Button* b) {
 	placeButtons();
 }
 
-Menu::Menu(SDL_Renderer* screen) {
-	this->screen = screen;
-	buttons = std::vector<Button*>(10);
-	isSubmenu = true;
+Menu::Menu(SDL_Renderer* screen) : buttons{std::vector<Button*>(10)}, isSubmenu{true}, screen{screen} {
 	exit.setLabel( _("Back") );
 }
 
-Menu::Menu(SDL_Renderer* screen,bool submenu) {
-	this->screen = screen;
-	buttons = std::vector<Button*>(0);
-	isSubmenu = submenu;
+Menu::Menu(SDL_Renderer* screen,bool submenu) : buttons{std::vector<Button*>(0)}, isSubmenu{submenu}, screen{screen} {
 	if (isSubmenu) {
 		exit.setLabel( _("Back") );
 	}
@@ -171,10 +155,7 @@ Menu::Menu(SDL_Renderer* screen,bool submenu) {
 	}
 }
 
-Menu::Menu(SDL_Renderer* screen, const std::string& title, bool submenu) : title{title} {
-	this->screen = screen;
-	buttons = std::vector<Button*>(0);
-	isSubmenu = submenu;
+Menu::Menu(SDL_Renderer* screen, const std::string& title, bool submenu) : buttons{std::vector<Button*>(0)}, isSubmenu{submenu}, screen{screen}, title{title} {
 	if (isSubmenu) {
 		exit.setLabel(_("Back") );
 	}
@@ -189,22 +170,7 @@ bool isUpEvent(const SDL_Event& event) {
 			return true;
 		}
 	}
-	if (event.type == SDL_CONTROLLERBUTTONDOWN) {
-		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_DPAD_UP ) {
-			return true;
-		}
-	}
-	if (event.type == SDL_CONTROLLERAXISMOTION  && event.caxis.axis == SDL_CONTROLLER_AXIS_LEFTY ) {
-		checkDeadZone(event);
-		const SDL_ControllerAxisEvent& a = event.caxis;
-		if (getDeadZone(a.which, a.axis)) {
-			if (event.caxis.value < -deadZoneLimit) {
-				setDeadZone(a.which,a.axis,false);
-				return true;
-			}
-		}
-	}
-	return false;
+	return isControllerUpEvent(event);
 }
 
 bool isDownEvent(const SDL_Event& event) {
@@ -213,22 +179,7 @@ bool isDownEvent(const SDL_Event& event) {
 			return true;
 		}
 	}
-	if (event.type == SDL_CONTROLLERBUTTONDOWN) {
-		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_DPAD_DOWN ) {
-			return true;
-		}
-	}
-	if (event.type == SDL_CONTROLLERAXISMOTION  && event.caxis.axis == SDL_CONTROLLER_AXIS_LEFTY ) {
-		checkDeadZone(event);
-		const SDL_ControllerAxisEvent& a = event.caxis;
-		if (getDeadZone(a.which, a.axis)) {
-			if (event.caxis.value > deadZoneLimit) {
-				setDeadZone(a.which,a.axis,false);
-				return true;
-			}
-		}
-	}
-	return false;
+	return isControllerDownEvent(event);
 }
 
 bool isLeftEvent(const SDL_Event& event) {
@@ -237,22 +188,7 @@ bool isLeftEvent(const SDL_Event& event) {
 			return true;
 		}
 	}
-	if (event.type == SDL_CONTROLLERBUTTONDOWN) {
-		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_DPAD_LEFT ) {
-			return true;
-		}
-	}
-	if (event.type == SDL_CONTROLLERAXISMOTION  && event.caxis.axis == SDL_CONTROLLER_AXIS_LEFTX ) {
-		checkDeadZone(event);
-		const SDL_ControllerAxisEvent& a = event.caxis;
-		if (getDeadZone(a.which, a.axis)) {
-			if (event.caxis.value < -deadZoneLimit) {
-				setDeadZone(a.which,a.axis,false);
-				return true;
-			}
-		}
-	}
-	return false;
+	return isControllerLeftEvent(event);
 }
 
 bool isRightEvent(const SDL_Event& event) {
@@ -261,22 +197,7 @@ bool isRightEvent(const SDL_Event& event) {
 			return true;
 		}
 	}
-	if (event.type == SDL_CONTROLLERBUTTONDOWN) {
-		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_DPAD_RIGHT ) {
-			return true;
-		}
-	}
-	if (event.type == SDL_CONTROLLERAXISMOTION  && event.caxis.axis == SDL_CONTROLLER_AXIS_LEFTX ) {
-		checkDeadZone(event);
-		const SDL_ControllerAxisEvent& a = event.caxis;
-		if (getDeadZone(a.which, a.axis)) {
-			if (event.caxis.value > deadZoneLimit) {
-				setDeadZone(a.which,a.axis,false);
-				return true;
-			}
-		}
-	}
-	return false;
+	return isControllerRightEvent(event);
 }
 
 bool isEscapeEvent(const SDL_Event& event) {
@@ -286,7 +207,7 @@ bool isEscapeEvent(const SDL_Event& event) {
 		}
 	}
 	if (event.type == SDL_CONTROLLERBUTTONDOWN) {
-		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_Y || event.cbutton.button == SDL_CONTROLLER_BUTTON_BACK ) {
+		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_B || event.cbutton.button == SDL_CONTROLLER_BUTTON_BACK ) {
 			return true;
 		}
 	}
@@ -300,7 +221,7 @@ bool isConfirmEvent(const SDL_Event& event) {
 		}
 	}
 	if (event.type == SDL_CONTROLLERBUTTONDOWN) {
-		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_A || event.cbutton.button == SDL_CONTROLLER_BUTTON_B ) {
+		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_A ) {
 			return true;
 		}
 	}
@@ -334,6 +255,12 @@ void Menu::Draw(SDL_Renderer* target) {
 #endif
 }
 void Menu::ProcessInput(const SDL_Event& event, bool& processed) {
+	if (isGameControllerConnectionEvent(event)) {
+		UnInitGameControllers();
+		InitGameControllers();
+		processed = true;
+	}
+
 	if (isUpEvent(event)) {
 		marked--;
 		if (marked<0) {
