@@ -39,6 +39,7 @@ struct ControllerStatus {
 static std::map<SDL_JoystickID, ControllerStatus> controllerStatusMap;
 static std::map<std::string, int> gamecontrollers_assigned;
 static std::vector<std::string> supportedControllers;
+static std::vector<SDL_GameController*> controllersOpened;
 
 
 void GameControllerSetVerbose(bool value) {
@@ -82,6 +83,19 @@ static int GetNextPlayerByGui(const SDL_JoystickGUID& guid) {
 	return 1;
 }
 
+void UnInitGameControllers() {
+	if (controllersOpened.empty()) {
+		return;
+	}
+	for (SDL_GameController* t : controllersOpened) {
+		SDL_GameControllerClose(t);
+	}
+	controllersOpened.clear();
+	controllerStatusMap.clear();
+	gamecontrollers_assigned.clear();
+	supportedControllers.clear();
+}
+
 void InitGameControllers() {
 	std::string configFile = sago::getConfigHome()+"/blockattack/gamecontrollerdb.txt";
 	int errorCode = SDL_GameControllerAddMappingsFromFile(configFile.c_str());
@@ -101,6 +115,7 @@ void InitGameControllers() {
 			int assingToPlayer = GetNextPlayerByGui(guid);
 			controllerStatusMap[instanceId].player = assingToPlayer;
 			supportedControllers.push_back(GameControllerGetName(controller));
+			controllersOpened.push_back(controller);
 			if (verbose) {
 				std::cout << "Supported game controller detected: " << GameControllerGetName(controller) << ", mapping: " << SDL_GameControllerMapping(controller) <<  "\n";
 				std::cout << "Assigned to player: " << controllerStatusMap[instanceId].player << "\n";
@@ -148,10 +163,17 @@ static bool skipThisPlayer(int playerNumber, const SDL_Event& event) {
 	return true;
 }
 
-bool isPlayerDownEvent(int playerNumber, const SDL_Event& event) {
-	if (skipThisPlayer(playerNumber, event)) {
-		return false;
+
+bool isGameControllerConnectionEvent(const SDL_Event& event) {
+	if ( event.type == SDL_CONTROLLERDEVICEADDED
+	        || event.type == SDL_CONTROLLERDEVICEREMOVED
+	        || event.type == SDL_CONTROLLERDEVICEREMAPPED ) {
+		return true;
 	}
+	return false;
+}
+
+bool isControllerDownEvent(const SDL_Event& event) {
 	if (event.type == SDL_CONTROLLERBUTTONDOWN) {
 		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_DPAD_DOWN ) {
 			return true;
@@ -170,10 +192,14 @@ bool isPlayerDownEvent(int playerNumber, const SDL_Event& event) {
 	return false;
 }
 
-bool isPlayerUpEvent(int playerNumber, const SDL_Event& event) {
+bool isPlayerDownEvent(int playerNumber, const SDL_Event& event) {
 	if (skipThisPlayer(playerNumber, event)) {
 		return false;
 	}
+	return isControllerDownEvent(event);
+}
+
+bool isControllerUpEvent(const SDL_Event& event) {
 	if (event.type == SDL_CONTROLLERBUTTONDOWN) {
 		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_DPAD_UP ) {
 			return true;
@@ -192,10 +218,14 @@ bool isPlayerUpEvent(int playerNumber, const SDL_Event& event) {
 	return false;
 }
 
-bool isPlayerLeftEvent(int playerNumber, const SDL_Event& event) {
+bool isPlayerUpEvent(int playerNumber, const SDL_Event& event) {
 	if (skipThisPlayer(playerNumber, event)) {
 		return false;
 	}
+	return isControllerUpEvent(event);
+}
+
+bool isControllerLeftEvent(const SDL_Event& event) {
 	if (event.type == SDL_CONTROLLERBUTTONDOWN) {
 		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_DPAD_LEFT ) {
 			return true;
@@ -214,10 +244,14 @@ bool isPlayerLeftEvent(int playerNumber, const SDL_Event& event) {
 	return false;
 }
 
-bool isPlayerRightEvent(int playerNumber, const SDL_Event& event) {
+bool isPlayerLeftEvent(int playerNumber, const SDL_Event& event) {
 	if (skipThisPlayer(playerNumber, event)) {
 		return false;
 	}
+	return isControllerLeftEvent(event);
+}
+
+bool isControllerRightEvent(const SDL_Event& event) {
 	if (event.type == SDL_CONTROLLERBUTTONDOWN) {
 		if (event.cbutton.button == SDL_CONTROLLER_BUTTON_DPAD_RIGHT ) {
 			return true;
@@ -236,6 +270,13 @@ bool isPlayerRightEvent(int playerNumber, const SDL_Event& event) {
 	return false;
 }
 
+bool isPlayerRightEvent(int playerNumber, const SDL_Event& event) {
+	if (skipThisPlayer(playerNumber, event)) {
+		return false;
+	}
+	return isControllerRightEvent(event);
+}
+
 bool isPlayerSwitchEvent(int playerNumber, const SDL_Event& event) {
 	if (skipThisPlayer(playerNumber, event)) {
 		return false;
