@@ -30,10 +30,6 @@ http://blockattack.net
 #include "HelpAboutState.hpp"
 #include "ShowFileState.hpp"
 
-using std::string;
-using std::cerr;
-using std::cout;
-using std::vector;
 
 #if 0
 //Menu
@@ -56,8 +52,8 @@ void OpenScoresDisplay();
 extern control keySettings[3];
 
 //Function to return the name of a key, to be displayed...
-string getKeyName(SDL_Keycode key) {
-	string keyname(SDL_GetKeyName(key));
+std::string getKeyName(SDL_Keycode key) {
+	std::string keyname(SDL_GetKeyName(key));
 	if (key == SDLK_UP) {
 		keyname = _("Up arrow");
 	}
@@ -95,7 +91,7 @@ string getKeyName(SDL_Keycode key) {
 		keyname = _("Space");
 	}
 	if (globalData.verboseLevel) {
-		cout << key << " translated to " << keyname << "\n";
+		std::cout << key << " translated to " << keyname << "\n";
 	}
 	return keyname;
 }
@@ -103,16 +99,15 @@ string getKeyName(SDL_Keycode key) {
 class Button_changekey : public Button {
 private:
 	SDL_Keycode* m_key2change;
-	string m_keyname;
+	std::string m_keyname;
 public:
-	Button_changekey(SDL_Keycode* key, string keyname);
+	Button_changekey(SDL_Keycode* key, const char* keyname);
 	void doAction();
 };
 
 
-Button_changekey::Button_changekey(SDL_Keycode* key, string keyname) {
-	m_key2change = key;
-	m_keyname = keyname;
+Button_changekey::Button_changekey(SDL_Keycode* key, const char* keyname)
+	: m_key2change{key}, m_keyname{keyname} {
 	setLabel(m_keyname+" : "+getKeyName(*m_key2change));
 }
 
@@ -212,8 +207,8 @@ static void runTwoPlayerVs() {
 
 static void SetAlwaysSoftwareLabel(Button* b) {
 	b->setLabel(Config::getInstance()->getInt("always-software")?
-			_("Always use software render: On")
-			: _("Always use software render: Off"));
+	            _("Always use software render: On")
+	            : _("Always use software render: Off"));
 }
 
 static void SetMusicLabel (Button* b) {
@@ -449,7 +444,9 @@ void SafeModeMenu() {
 	bOnce.setLabel(_("Use software renderer this time"));
 	bAlways.setLabel(_("Always use software renderer"));
 	bOnce.setPopOnRun(true);
-	bAlways.setAction([]() {Config::getInstance()->setInt("always-software", 1); });
+	bAlways.setAction([]() {
+		Config::getInstance()->setInt("always-software", 1);
+	});
 	bAlways.setPopOnRun(true);
 	safeMode.addButton(&bOnce);
 	safeMode.addButton(&bAlways);
